# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.1.0] - 2022/01/31

### Added

* Blocked testcases are in blue color now
* Errors in setup or teardown are shown
* We have unittests now :rocket:

## [1.0.2] - 2022/01/25

### Fixed

* Fix XFAIL/XPASS handling

## [1.0.1] - 2021/11/24

### Fixed

* Fix setup

## [1.0.0] - 2021/11/24

First publicly available version.
